"""
Generates ascii grids of nominated areas -
Input: sww file from run_perth.py
       boundaries for grids from project.py
Outputs: ascii grids of specified variables
Stored in the 'outputs_dir' folder for respective .sww file

Note:
If producing a grid for the enitre extent cellsize should be greater than 30m
If producing grids for inundation area resolution should be greater than mesh (ie ~22m)
"""

import project, os
import sys
from os.path import join
from anuga.lib.maxasc.maxasc import MaxAsc
from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts
from anuga.shallow_water.data_manager import sww2dem
from os import sep


directory = project.output_folder


time_dir1 = '20090408_090633_run_final_0.8_mux_small_final_onielsen'
time_dir2 = '20090407_171956_run_final_0.8_mux_small_no_buildings_onielsen'
time_dir3 = '20090407_172311_run_final_0.8_mux_small_f0.0003_onielsen'
time_dir4 = '20090407_172145_run_final_0.8_mux_small_f0.03_onielsen'
time_dir5 = '20090408_090831_run_final_0.8_mux_small_plus10cm_onielsen'
time_dir6 = '20090408_092934_run_final_0.8_mux_small_minus10cm_onielsen'
time_dir7 = '20090401_104100_run_final_0.8_mux_small_viz_onielsen'


time_dirs = [time_dir6] #, time_dir2,time_dir3, time_dir4,time_dir5, time_dir6, time_dir7]
  

# sww filename extensions ie. hobart_time_17640_0.sww, input into list 17640
# make sure numbers are in sequential order
times = []
            
#Modify the cellsize value to set the size of the raster you require
#Take into account mesh size when aplying this paramater
cellsize = 10 #250

#Now set the timestep at which you want the raster generated.
#Either set the actual timestep required or use 'None' to indicate that
#you want the maximum values in the raster over all timesteps
timestep = None   #0 

# Set the special areas of interest.  If none, do: area=['All']
# Areas identified below are specified by cooridinates in project.py  

area = ['CBD']  
#area = ['All']      

# one or more key strings from var_equations below
var = ['speed']

######
# Define allowed variable names and associated equations to generate values.
# This would not normally change.
######
var_equations = {'stage':     'stage',
                 'momentum':  '(xmomentum**2 + ymomentum**2)**0.5',
                 'depth':     'stage-elevation',
                 'speed':     '(xmomentum**2 + ymomentum**2)**0.5/(stage-elevation+1.e-6)',
                 'elevation': 'elevation' }


######
# Start script, running through variables, area, folder, sww file (determine by times)
# Then creates a maximum asci if there is more than one sww file
######

for which_var in var:
    if which_var not in var_equations:
        print 'Unrecognized variable name: %s' % which_var
        break

    for which_area in area:
        if which_area == 'All':
            easting_min = None
            easting_max = None
            northing_min = None
            northing_max = None
        else:
            try:
                easting_min = eval('project.xmin%s' % which_area)
                easting_max = eval('project.xmax%s' % which_area)
                northing_min = eval('project.ymin%s' % which_area)
                northing_max = eval('project.ymax%s' % which_area)
            except AttributeError:
                print 'Unrecognized area name: %s' % which_area
                break

        for time_dir in time_dirs:
            names = [join(directory, time_dir, project.scenario_name)]
            for time in times:
                names.append(join(directory, time_dir, project.scenario_name)+ '_time_' + str(time) + '_0')
            
            asc_name = []   
                           
            for name in names:
                outname = name + '_' + which_area + '_' + which_var + '_' + str(cellsize)
                quantityname = var_equations[which_var]
                
                print 'start sww2dem: time_dir=%s' % time_dir
                print 'name=%s' % name
                sww2dem(name, basename_out = outname,
                            quantity = quantityname,
                            timestep = timestep,
                            cellsize = cellsize,      
                            easting_min = easting_min,
                            easting_max = easting_max,
                            northing_min = northing_min,
                            northing_max = northing_max,        
                            reduction = max, 
                            verbose = True,
                            format = 'asc')

                asc_name.append(outname + '.asc')
            
            if len(names) >1:
                maxasc_outname = join(directory, time_dir, project.scenario_name)+'_'
                +which_area+'_'+which_var+'_'+str(cellsize)+'_max.asc'

                print 'max asc outname ', maxasc_outname
                print 'asc_name ', str(asc_name)
                
                MaxAsc(maxasc_outname, asc_name)
            else:
                print 'Only one sww file, no Max file required' 
